import React, { useState, useEffect, useRef } from 'react';
import Chart from 'chart.js/auto';

interface Blockchain {
  metadata: {
    id: number;
    name: string;
    description: string;
    thumbnail_url: string;
    currency_id: string;
    latest_data_timestamp: string;
  };
}

const ContentPage: React.FC = () => {
  const [blockchains, setBlockchains] = useState<Blockchain[]>([]);
  const [isLoading, setIsLoading] = useState<boolean>(true);
  const [error, setError] = useState<string | null>(null);
  const chartRef = useRef<Chart<"pie"> | null>(null);

  useEffect(() => {
    const fetchData = async () => {
      try {
        setIsLoading(true);

        const response = await fetch('https://api.unleashnfts.com/api/v1/blockchains?sort_by=blockchain_name&offset=0&limit=30', {
          headers: {
            'x-api-key': '24055130acb662ec9ecace3148765f73'
          }
        });

        if (!response.ok) {
          throw new Error('Failed to fetch data');
        }

        const jsonData = await response.json();

        setBlockchains(jsonData.blockchains);
        setError(null);
      } catch (error) {
        setError('Failed to fetch data');
      } finally {
        setIsLoading(false);
      }
    };

    fetchData();
  }, []);

  useEffect(() => {
    if (!blockchains.length) return;

    const currencies: { [currency: string]: number } = {};

    blockchains.forEach(blockchain => {
      const currency = blockchain.metadata.currency_id;
      if (currencies[currency]) {
        currencies[currency]++;
      } else {
        currencies[currency] = 1;
      }
    });

    const labels = Object.keys(currencies);
    const data = Object.values(currencies);

    const ctx = document.getElementById('blockchainChart') as HTMLCanvasElement;
    if (chartRef.current) {
      chartRef.current.destroy();
    }
    chartRef.current = new Chart(ctx, {
      type: 'pie',
      data: {
        labels: labels,
        datasets: [{
          label: 'Blockchain Currencies Distribution',
          data: data,
          backgroundColor: [
            'rgba(255, 99, 132, 0.5)',
            'rgba(54, 162, 235, 0.5)',
            'rgba(255, 206, 86, 0.5)',
            'rgba(75, 192, 192, 0.5)',
            'rgba(153, 102, 255, 0.5)',
            'rgba(255, 159, 64, 0.5)'
          ],
          borderColor: [
            'rgba(255, 99, 132, 1)',
            'rgba(54, 162, 235, 1)',
            'rgba(255, 206, 86, 1)',
            'rgba(75, 192, 192, 1)',
            'rgba(153, 102, 255, 1)',
            'rgba(255, 159, 64, 1)'
          ],
          borderWidth: 1
        }]
      },
      options: {
        responsive: true,
        plugins: {
          legend: {
            position: 'top',
          },
          title: {
            display: true,
            text: 'Blockchain Currencies Distribution'
          }
        }
      }
    });
  }, [blockchains]);

  if (isLoading) {
    return <div>Loading...</div>;
  }

  if (error) {
    return <div>Error: {error}</div>;
  }

  return (
    <div>
      <h1>Blockchain Currencies Distribution</h1>
      <h2>hello</h2>
      <canvas id="blockchainChart" width={300} height={300}></canvas>
    </div>
  );
};

export default ContentPage;
